@@ -1,4 +1,4 @@
 PACKAGE = "cptrace"
 VERSION = "0.6.1"
-WEBSITE = "http://python-ptrace.hachoir.org/"
+WEBSITE = "http://python-ptrace.readthedocs.io/"
 LICENSE = "GNU GPL v2"
